==> jc-1.4.0.tar.gz: java/awt/dnd/DropTargetEvent.h <==
// public class java.awt.dnd.DropTargetEvent

// class file dependencies
// @dep_class fb6fee3e34aaae16 java_awt_dnd_DropTargetEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_java_awt_dnd_DropTargetEvent_H_
#define _JC_java_awt_dnd_DropTargetEvent_H_

// Forward structure declarations
struct _jc_java_awt_dnd_DropTargetContext$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DropTargetEvent$sub_refs	_jc_java_awt_dnd_DropTargetEvent$sub_refs;
typedef struct _jc_java_awt_dnd_DropTargetEvent$sub_nonrefs	_jc_java_awt_dnd_DropTargetEvent$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetEvent$refs	_jc_java_awt_dnd_DropTargetEvent$refs;
typedef struct _jc_java_awt_dnd_DropTargetEvent$nonrefs	_jc_java_awt_dnd_DropTargetEvent$nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetEvent$object	_jc_java_awt_dnd_DropTargetEvent$object;

typedef const struct _jc_java_awt_dnd_DropTargetEvent$vmethods	_jc_java_awt_dnd_DropTargetEvent$vmethods;
typedef const struct _jc_java_awt_dnd_DropTargetEvent$vtable	_jc_java_awt_dnd_DropTargetEvent$vtable;
typedef const struct _jc_java_awt_dnd_DropTargetEvent$vtype	_jc_java_awt_dnd_DropTargetEvent$vtype;

// Constructors
extern void _jc_java_awt_dnd_DropTargetEvent$method$_init$f7d4054c820b80a8(_jc_env *, struct _jc_java_awt_dnd_DropTargetEvent$object *, struct _jc_java_awt_dnd_DropTargetContext$object *);

// Virtual methods
extern struct _jc_java_awt_dnd_DropTargetContext$object *_jc_java_awt_dnd_DropTargetEvent$method$getDropTargetContext$c80b1e104d7e50c1(_jc_env *, struct _jc_java_awt_dnd_DropTargetEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DropTargetEvent$method_info$getDropTargetContext$c80b1e104d7e50c1;

// Virtual methods structure
struct _jc_java_awt_dnd_DropTargetEvent$vmethods {
	struct _jc_java_awt_dnd_DropTargetContext$object	*(*getDropTargetContext$c80b1e104d7e50c1)(_jc_env *, struct _jc_java_awt_dnd_DropTargetEvent$object *);
};

// Vtable
struct _jc_java_awt_dnd_DropTargetEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_dnd_DropTargetEvent$vmethods	java_awt_dnd_DropTargetEvent;
};

// Vtype
struct _jc_java_awt_dnd_DropTargetEvent$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DropTargetEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetEvent$sub_refs {
	struct _jc_java_awt_dnd_DropTargetContext$object	*context;
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetEvent$refs {
    _jc_java_awt_dnd_DropTargetEvent$sub_refs	java_awt_dnd_DropTargetEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_dnd_DropTargetEvent$sub_nonrefs	java_awt_dnd_DropTargetEvent;
};

// Object instance structure
struct _jc_java_awt_dnd_DropTargetEvent$object {
	_jc_java_awt_dnd_DropTargetEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DropTargetEvent$vtype	*vtype;
	_jc_java_awt_dnd_DropTargetEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DropTargetEvent$vtype _jc_java_awt_dnd_DropTargetEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DropTargetEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DropTargetEvent$class_object;

#endif	/* _JC_java_awt_dnd_DropTargetEvent_H_ */

==> jc-1.4.6.tar.gz: java/awt/dnd/DropTargetEvent.h <==
// public class java.awt.dnd.DropTargetEvent

// class file dependencies
// @dep_class fb6fee3e34aaae16 java_awt_dnd_DropTargetEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_java_awt_dnd_DropTargetEvent_H_
#define _JC_java_awt_dnd_DropTargetEvent_H_

// Forward structure declarations
struct _jc_java_awt_dnd_DropTargetContext$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DropTargetEvent$sub_refs	_jc_java_awt_dnd_DropTargetEvent$sub_refs;
typedef struct _jc_java_awt_dnd_DropTargetEvent$sub_nonrefs	_jc_java_awt_dnd_DropTargetEvent$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetEvent$refs	_jc_java_awt_dnd_DropTargetEvent$refs;
typedef struct _jc_java_awt_dnd_DropTargetEvent$nonrefs	_jc_java_awt_dnd_DropTargetEvent$nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetEvent$object	_jc_java_awt_dnd_DropTargetEvent$object;

typedef const struct _jc_java_awt_dnd_DropTargetEvent$vmethods	_jc_java_awt_dnd_DropTargetEvent$vmethods;
typedef const struct _jc_java_awt_dnd_DropTargetEvent$vtable	_jc_java_awt_dnd_DropTargetEvent$vtable;
typedef const struct _jc_java_awt_dnd_DropTargetEvent$vtype	_jc_java_awt_dnd_DropTargetEvent$vtype;

// Constructors
extern void _jc_java_awt_dnd_DropTargetEvent$method$_init$f7d4054c820b80a8(_jc_env *, struct _jc_java_awt_dnd_DropTargetEvent$object *, struct _jc_java_awt_dnd_DropTargetContext$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_dnd_DropTargetContext$object *_jc_java_awt_dnd_DropTargetEvent$method$getDropTargetContext$c80b1e104d7e50c1(_jc_env *, struct _jc_java_awt_dnd_DropTargetEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DropTargetEvent$method_info$getDropTargetContext$c80b1e104d7e50c1;

// Virtual methods structure
struct _jc_java_awt_dnd_DropTargetEvent$vmethods {
	struct _jc_java_awt_dnd_DropTargetContext$object	*(*getDropTargetContext$c80b1e104d7e50c1)(_jc_env *, struct _jc_java_awt_dnd_DropTargetEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_dnd_DropTargetEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_dnd_DropTargetEvent$vmethods	java_awt_dnd_DropTargetEvent;
};

// Vtype
struct _jc_java_awt_dnd_DropTargetEvent$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DropTargetEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetEvent$sub_refs {
	struct _jc_java_awt_dnd_DropTargetContext$object	*context;
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetEvent$refs {
    _jc_java_awt_dnd_DropTargetEvent$sub_refs	java_awt_dnd_DropTargetEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_dnd_DropTargetEvent$sub_nonrefs	java_awt_dnd_DropTargetEvent;
};

// Object instance structure
struct _jc_java_awt_dnd_DropTargetEvent$object {
	_jc_java_awt_dnd_DropTargetEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DropTargetEvent$vtype	*vtype;
	_jc_java_awt_dnd_DropTargetEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DropTargetEvent$vtype _jc_java_awt_dnd_DropTargetEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DropTargetEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DropTargetEvent$class_object;

#endif	/* _JC_java_awt_dnd_DropTargetEvent_H_ */
